import * as rt from "regular-table";
import { Content, IContentRow } from "../content";
import { ContentsModel } from "../model";
import { TreeFinderFiltersElement } from "./filters";
declare const RegularTableElement: typeof rt.RegularTableElement;
export declare class TreeFinderGridElement<T extends IContentRow> extends RegularTableElement {
    init(model: ContentsModel<T>, options?: TreeFinderGridElement.IOptions<T>): Promise<void>;
    dataListener(start_col: number, start_row: number, end_col: number, end_row: number): Promise<{
        num_columns: number;
        num_rows: number;
        column_headers: ChildNode[][];
        row_headers: ([HTMLSpanElement] | [string, HTMLSpanElement])[];
        data: any[][];
    }>;
    columnHeaderStyleListener(): void;
    columnWidthStyleListener(): void;
    cornerHeaderStyleListener(): void;
    rowStyleListener(): void;
    onMouseover(event: MouseEvent): Promise<void>;
    onRowClick(event: MouseEvent): Promise<void>;
    onSortClick(event: MouseEvent): Promise<void>;
    onTreeClick(event: MouseEvent): Promise<void>;
    onRowDoubleClick(event: MouseEvent): Promise<void>;
    get options(): TreeFinderGridElement.IOptions<T>;
    set options({ columnFormatters, doWindowResize, pathRender, pathRenderOnFilter, showFilter, virtual_mode, }: TreeFinderGridElement.IOptions<T>);
    set showFilter(flag: boolean);
    protected _getData(start_col: number, start_row: number, end_col: number, end_row: number): T[keyof T][][];
    protected _getRowHeader(target: Content<T>): [HTMLSpanElement] | [string, HTMLSpanElement];
    protected _renamerStyleListener(element: HTMLElement, target: Content<T>): void;
    protected _selectedStyleListener(): void;
    protected get _pathRender(): "regular" | "relative" | "tree";
    protected _options: TreeFinderGridElement.IOptions<T>;
    protected filters?: TreeFinderFiltersElement<T>;
    protected model: ContentsModel<T>;
    private _initializedListeners;
}
export declare namespace TreeFinderGridElement {
    interface IOptions<T extends IContentRow> {
        columnFormatters?: {
            [key in keyof T]?: (datum: T[key]) => any;
        };
        /**
         * if true, redraw the tree-finder-grid element on window resize events
         */
        doWindowResize?: boolean;
        /**
         * select from different strategies for rendcering the paths
         */
        pathRender?: "regular" | "relative" | "tree";
        /**
         * if not null, the rendering of paths will change when any filter is set
         */
        pathRenderOnFilter?: "regular" | "relative" | "tree";
        /**
         * if true, add filter inputs to top of each colum
         */
        showFilter?: boolean;
        /**
         * pass through to .setDataListener "virtual_mode" opt
         */
        virtual_mode?: "both" | "horizontal" | "none" | "vertical";
    }
}
export {};
//# sourceMappingURL=grid.d.ts.map