import { BehaviorSubject, Subject } from "rxjs";
import { Content, IContentRow } from "../content";
import { FilterPatterns, SortStates } from "../filtersort";
import { Path } from "../util";
declare class CrumbModel<T extends IContentRow> {
    constructor();
    revert(crumbIx: number): T | undefined;
    extend(crumbs: T[]): T;
    protected _onCrumbUpdate(): Promise<void>;
    readonly crumbNamesSub: BehaviorSubject<string[]>;
    readonly revertedCrumbSub: BehaviorSubject<T | undefined>;
    protected _crumbsRows: T[];
}
export declare class ContentsModel<T extends IContentRow> {
    constructor(root: T, options?: ContentsModel.IOptions<T>);
    open(root: T): Promise<void>;
    openDir(root: T): Promise<void>;
    initColumns(): void;
    collapse(rix: number): Promise<void>;
    expand(rix: number): Promise<void>;
    filter(props?: {
        autosize?: boolean;
    }): Promise<void>;
    onFilterInput(fpat: {
        col: keyof T;
        pattern: string;
    }): void;
    requestDraw(props?: {
        autosize?: boolean;
        delay?: number;
    }): void;
    sort(props?: {
        col?: keyof T;
        multisort?: boolean;
        autosize?: boolean;
    }): Promise<void>;
    get columns(): (keyof T)[];
    get contents(): Content<T>[];
    get filterPatterns(): FilterPatterns<T>;
    get isBlank(): number | false;
    get ixByColumn(): { [k in keyof T]: number; };
    get options(): ContentsModel.IOptions<T>;
    set options({ columnNames, doRefetch, needsWidths, }: ContentsModel.IOptions<T>);
    get pathDepth(): number;
    renamerTest(x: Content<T>): boolean;
    set renamerPath(path: Path.PathArray | null);
    get root(): Content<T>;
    get selection(): Content<T>[];
    get selectedLast(): Content<T> | null;
    get sortStates(): SortStates<T>;
    filterCol?: keyof T;
    readonly columnWidthsSub: BehaviorSubject<string[]>;
    readonly drawSub: BehaviorSubject<boolean>;
    readonly openSub: Subject<T>;
    readonly renamerSub: Subject<ContentsModel.IRenamer<T>>;
    readonly crumbModel: CrumbModel<T>;
    readonly selectionModel: SelectionModel<T>;
    protected _columns: (keyof T)[];
    protected _contents: Content<T>[];
    protected _filterContents: Content<T>[];
    protected _filterPatterns: FilterPatterns<T>;
    protected _parentMap: ContentsModel.RefMap<T>;
    protected _renamerPath: Path.PathArray | null;
    protected _root: Content<T>;
    protected _sortStates: SortStates<T>;
    protected _options: ContentsModel.IOptions<T>;
    private _ixByColumn;
}
export declare namespace ContentsModel {
    interface IOptions<T extends IContentRow> {
        /**
         * optionally specify the visible columns, and the order they appear in
         */
        columnNames?: (keyof T)[];
        /**
         * if true, always (re)fetch children when opening a dir
         */
        doRefetch?: boolean;
        /**
         * if true, the columnWidthsSub will emit the auto column widths on each draw cycle
         */
        needsWidths?: boolean;
    }
    interface IRenamer<T extends IContentRow> {
        name: string;
        target: Content<T>;
    }
    type RefMap<T extends IContentRow> = WeakMap<T, T>;
}
export declare class SelectionModel<T extends IContentRow> {
    constructor();
    clear(): void;
    get(contents: Content<T>[]): Content<T>[];
    getLast(contents: Content<T>[]): Content<T> | null;
    has(content: Content<T>): boolean;
    select(lastContent: Content<T>, add?: boolean): void;
    selectRange(lastContent: Content<T>, contents: Content<T>[]): void;
    get lastPathstr(): string | null;
    protected _lastPathstr: string | null;
    protected range: string[];
    protected pivot: string | null;
    protected selection: Set<string>;
}
export declare namespace SelectionModel {
    function findRange(start: string | null, end: string, vals: string[]): string[];
}
export {};
//# sourceMappingURL=model.d.ts.map