import { MetaData, RegularTableElement } from "regular-table";
export declare namespace Format {
    const DATE_FORMATTER: Intl.DateTimeFormat;
    /**
     * Format bytes as human-readable text.
     * ref: https://stackoverflow.com/a/14919494
     *
     * @param bytes Number of bytes.
     * @param si True to use metric (SI) units, aka powers of 1000. False to use
     *           binary (IEC), aka powers of 1024.
     * @param dp Number of decimal places to display.
     *
     * @return Formatted string.
     */
    function bytesToHumanReadable(bytes: number, si?: boolean, dp?: number): string;
    function dateToStr(date: Date, str: string): boolean;
    function timeSince(date: Date | string): string;
}
export declare namespace RegularTable {
    function cellClicked(metadata: MetaData): boolean;
    function columnHeaderClicked(metadata: MetaData): boolean;
    function rowClicked(metadata: MetaData): boolean;
    function rowHeaderClicked(metadata: MetaData): boolean;
    function clickLoggingListener(event: MouseEvent, rt: RegularTableElement): void;
    function colNameFromMeta(meta: MetaData): string;
    function metadataFromElement(target: Element, rt: RegularTableElement, recursive?: boolean): MetaData | undefined;
}
export declare namespace Path {
    type PathArray = string[];
    function equal(l: PathArray, r: PathArray): boolean;
    function fromarray(x: PathArray): string;
    function toarray(x: string): PathArray;
    /**
     * remove all back/slashes, then add a trailing slash if requested to a string
     */
    function normSlash(x: string, trailing: boolean): string;
    /**
     * remove all back/slashes from string
     */
    function trimSlash(x: string): string;
}
export declare namespace Tag {
    export const html: (strings: TemplateStringsArray, ...args: any[]) => string;
    /**
     * for generating element attributes in html markup
     */
    type attrSpec = {
        key: string;
        values: (boolean | string)[];
    };
    export const attrs: (specs: attrSpec[]) => string;
    export {};
}
export declare namespace Trait {
    type Keyof<T> = Exclude<keyof T, number>;
}
export declare namespace Tree {
    function breadcrumbsSpans(path: string[]): string;
    function colHeaderSpans(name: string, filter?: boolean): ChildNode[];
    function rowHeaderSpan({ isDir, isExpand: isOpen, path, editable, pathRender }: {
        isDir: boolean;
        isExpand: boolean;
        path: string[];
        editable?: boolean;
        pathRender?: "regular" | "relative" | "tree";
    }): ([HTMLSpanElement] | [string, HTMLSpanElement]);
}
//# sourceMappingURL=util.d.ts.map